## acquire TCGA data
rm(list=ls())

## set to working directory
setwd("~/Desktop/survival/docs/data/kidney/")
source("TCGA-Assembler/Module_A.R")
source("TCGA-Assembler/Module_B.R")


## cancer type
sCancer <- "KIRC"


###### STEP 1: GET rna and snv data
sPath <- "kidney_data"
path_geneExp <- DownloadRNASeqData(cancerType = sCancer,
                                   assayPlatform = "gene.normalized_RNAseq",
                                   saveFolderName = sPath)
rna <- read.table(path_geneExp,header=TRUE,row.names=1)
dim(rna)
head(rna[,1])
rna <- t(as.matrix(rna))

path_somaticMutation <- DownloadSomaticMutationData(cancerType=sCancer,
                              assayPlatform="somaticMutation_DNAseq",
                              saveFolderName=sPath)
path_somaticMutation
snv <- read.table(path_somaticMutation[1],
                  header=TRUE,sep="\t",stringsAsFactors=FALSE)
dim(snv)
colnames(snv)

## we summarize the data by setting mutation = 1 if gene has snv
## and =0 if not, only do for most common snvs

## get tumor barcodes
barcodes <- unique(snv$Tumor_Sample_Barcode)
## the number of unique tumor samples matches
## "Comprehensive molecular characterization of clear cell renal cell carcinoma"
length(barcodes)


## remove silent mutations
snv <- snv[snv$Variant_Classification!="Silent",]

snv_sub <- snv[,c("Tumor_Sample_Barcode","Hugo_Symbol")]
colnames(snv_sub) <- c("barcode","gene")
snv_sub <- snv_sub[!duplicated(snv_sub),]
nrow(snv_sub)

## get names of commonly mutated genes
snv_freqs <- table(snv_sub$gene)
common_mutated_genes <- names(snv_freqs)[snv_freqs >= 30]
common_mutated_genes

snv_freqs <- snv_freqs[snv_freqs >= 30]
data.frame(snv_freqs)

## put in matrix with rows=observations and columns=mutated genes
snv_present <- matrix(0,nrow=length(barcodes),ncol=length(common_mutated_genes))
colnames(snv_present) <- common_mutated_genes
rownames(snv_present) <- barcodes
for(ii in 1:ncol(snv_present)){
  snv_present[snv_sub[snv_sub[,2]==common_mutated_genes[ii],1],ii] <- 1
}


sum(snv_sub[,2]==common_mutated_genes[ii])
snv_sub[snv_sub[,2]==common_mutated_genes[ii],1]
sum(snv_present)
hist(rowSums(snv_present))
summary(rowSums(snv_present))
hist(colSums(snv_present))
hist(snv_freqs)
snv_freqs[common_mutated_genes] - colSums(snv_present)


###### STEP 2: GET CLINICAL
### downloaded from : https://portal.gdc.cancer.gov/exploration?filters=%7B%22op%22%3A%22and%22%2C%22content%22%3A%5B%7B%22op%22%3A%22in%22%2C%22content%22%3A%7B%22field%22%3A%22cases.primary_site%22%2C%22value%22%3A%5B%22Kidney%22%5D%7D%7D%5D%7D
### clinical -> .tsv
dat <- read.table("clinical.tsv",sep="\t",header=TRUE,
                  stringsAsFactors=FALSE,na.strings=c("NA","--"))
dat <- dat[dat$project_id=="TCGA-KIRC",]

## rule for survival
## if have death time, event time=death time AND not censored
## if no death time but time of last follow up, event time=time of last follow up AND censored
## individuals who do not have a death time or data of last follow up are removed
event_time <- dat$days_to_death
obs_death <- 1*(!is.na(event_time))
## everyone is either dead or has last follow up time
sum(is.na(dat$days_to_death))
sum(is.na(dat$days_to_death) & is.na(dat$days_to_last_follow_up))
event_time[is.na(event_time)] <- dat$days_to_last_follow_up[is.na(event_time)]

dat$event_time <- event_time
dat$obs_death <- obs_death
sum(is.na(dat$event_time))

## make kaplan meier survival curve for everyone
dim(dat)
library(survival)
fit <- survfit(Surv(dat$event_time/365,dat$obs_death)~1,
               conf.type="log-log")
par(mar=c(4,4,1,1))
plot(fit,mark.time=TRUE)
abline(h=.5,col='grey')
abline(h=.4,col='grey')


###### STEP 3: SELECT / MERGE DATA
snv <- snv_present

## some samples are of normal tissue. for example
## in code "TCGA-CZ-5985-11A-01R-1672-07" the "11A" indicates normal.
## we remove these rna expressions
## see: https://www.biostars.org/p/313063/ for description of bar code meanings
rownames(rna) <- gsub(".","-",rownames(rna),fixed=TRUE)
head(rownames(rna))
## only keep "01A" samples for rna
temp <- strsplit(rownames(rna),"-",fixed="TRUE")
temp <- vapply(temp,function(x){x[[4]]},c(""))
table(temp)
ix <- temp=="01A"
rna <- rna[ix,]
dim(rna)
## only keep "01A" samples for snv
temp <- strsplit(rownames(snv),"-",fixed="TRUE")
temp <- vapply(temp,function(x){x[[4]]},c(""))
table(temp)
ix <- temp=="01A"
snv <- snv[ix,]
dim(snv)

## remove 01W analytes, which are different than dna "D" analytes
temp <- strsplit(rownames(snv),"-",fixed="TRUE")
temp <- vapply(temp,function(x){x[[5]]},c(""))
snv <- snv[temp!="01W",]
dim(snv)

## remove small number of duplicates
snames <- substr(rownames(snv),1,12)
sum(duplicated(snames))
snv <- snv[!duplicated(snames),]


## nearly all snv in rna and all rna has clinical
## all rna data has clinical, 98% of clinical has rna
snames <- substr(rownames(snv),1,12)
rnames <- substr(rownames(rna),1,12)
length(snames)
length(unique(snames))
length(rnames)
length(unique(rnames))
mean(snames %in% rnames)
mean(rnames %in% snames)
head(rnames)
head(dat$submitter_id)
length(rnames)
length(dat$submitter_id)
length(unique(dat$submitter_id))
length(unique(rnames))
mean(dat$submitter_id %in% rnames)
mean(rnames %in% dat$submitter_id)

## only keep subjects for whom we have rna,dna,clinical
common_samples <- intersect(rnames,intersect(snames,dat$submitter_id))
length(common_samples)
dat <- dat[dat$submitter_id %in% common_samples,]
snv <- snv[snames %in% common_samples,]
rna <- rna[rnames %in% common_samples,]
dim(dat)
dim(snv)
dim(rna)

## order the clinical, rna, snv data
rna <- rna[order(rownames(rna)),]
snv <- snv[order(rownames(snv)),]
dat <- dat[order(dat$submitter_id),]
identical(substr(rownames(rna),1,12),dat$submitter_id)
identical(substr(rownames(snv),1,12),dat$submitter_id)

save(rna,dat,snv,file="tcga_kirc.RData")
